==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ast.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡Nun pue escribise nel direutoriu «config»!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Davezu esto pue iguase dándo-y al sirvidor web accesu d'escritura al direutoriu de configuración",
    "See %s" : "Mira %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Esto davezu íguase dando'l permisu d'escritura nel direutoriu de configuración al sirvidor web. Mira %s",
    "Sample configuration detected" : "Configuración d'amuesa detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectose que la configuración d'amuesa copiose. Esto pue encaboxar la instalación y dexala ensín soporte. Llee la documentación enantes de facer cambéos en config.php",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "Education Edition" : "Edición educativa",
    "Enterprise bundle" : "Llote empresarial",
    "Social sharing bundle" : "Llote de compartición social",
    "PHP %s or higher is required." : "Necesítase PHP %s o superior",
    "PHP with a version lower than %s is required." : "Necesítase una versión PHP anterior a %s",
    "%sbit or higher PHP required." : "Necesítase PHP %sbit o superior",
    "Following databases are supported: %s" : "Les siguientes bases de datos tan sofitaes: %s",
    "The command line tool %s could not be found" : "La ferramienta línea de comandu %s nun pudo alcontrase",
    "The library %s is not available." : "La librería %s nun ta disponible",
    "Following platforms are supported: %s" : "Les siguientes plataformes tan sofitaes: %s",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Triba de ficheru desconocida",
    "Invalid image" : "Imaxe inválida",
    "Avatar image is not square" : "La imaxe del avatar nun ye cuadrada",
    "today" : "güei",
    "tomorrow" : "mañana",
    "yesterday" : "ayeri",
    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n díes"],
    "last month" : "mes caberu",
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "last year" : "añu caberu",
    "_%n year ago_::_%n years ago_" : ["hai %n añu","hai %n años"],
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n hores"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minutu","hai %n minutos"],
    "seconds ago" : "hai segundos",
    "File name is a reserved word" : "El nome de ficheru ye una pallabra reservada",
    "File name contains at least one invalid character" : "El nome del ficheru contién polo menos un carácter non válidu",
    "File name is too long" : "El nome de ficheru ye demasiáu llargu",
    "Empty filename is not allowed" : "Nun s'almite un nome de ficheru baleru",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'aplicación \"%s\" nun puede instalase porque nun se llee'l ficheru appinfo.",
    "__language_name__" : "Asturianu",
    "Help" : "Ayuda",
    "Apps" : "Aplicaciones",
    "Settings" : "Settings",
    "Log out" : "Zarrar sesión",
    "Users" : "Usuarios",
    "Unknown user" : "Usuariu desconocíu",
    "Basic settings" : "Axustes básicos",
    "Sharing" : "Compartiendo",
    "Security" : "Seguranza",
    "Additional settings" : "Axustes adicionales",
    "Personal info" : "Información personal",
    "%s enter the database username and name." : "%s introducir el nome d'usuariu y el nome de la base de datos .",
    "%s enter the database username." : "%s introducir l'usuariu de la base de datos.",
    "%s enter the database name." : "%s introducir nome de la base de datos.",
    "%s you may not use dots in the database name" : "%s nun pues usar puntos nel nome de la base de datos",
    "Oracle connection could not be established" : "Nun pudo afitase la conexón d'Oracle",
    "Oracle username and/or password not valid" : "Nome d'usuariu o contraseña d'Oracle non válidos",
    "PostgreSQL username and/or password not valid" : "Nome d'usuariu o contraseña PostgreSQL non válidos",
    "You need to enter details of an existing account." : "Precises introducir los detalles d'una cuenta esistente.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nun ta sofitáu y %s nun furrulará afayadizamente nesta plataforma. ¡Úsalu baxo'l to riesgu!",
    "For the best results, please consider using a GNU/Linux server instead." : "Pa los meyores resultaos, por favor considera l'usu d'un sirvidor GNU/Linux nel so llugar.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Paez ser que la instancia %s ta executándose nun entornu de PHP 32 bits y el open_basedir configuróse en php.ini. Esto va dar llugar a problemes colos ficheros de más de 4 GB y nun ye nada recomendable.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, desanicia la configuración open_basedir dientro la so php.ini o camude a PHP 64 bits.",
    "Set an admin username." : "Afitar nome d'usuariu p'almin",
    "Set an admin password." : "Afitar contraseña p'almin",
    "Can't create or write into the data directory %s" : "Nun pue crease o escribir dientro los datos del direutoriu %s",
    "Invalid Federated Cloud ID" : "ID non válida de ñube federada",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartíu %s tien d'implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "Nun s'alcontró'l botón de compartición %s",
    "Sharing backend for %s not found" : "Nun s'alcontró'l botón de partición pa %s",
    "Open »%s«" : "Abrir «%s»",
    "You are not allowed to share %s" : "Nun tienes permisu pa compartir %s",
    "Can’t increase permissions of %s" : "Nun pue aumentase los permisos de %s",
    "Files can’t be shared with delete permissions" : "Los ficheros nun puen compartise colos permisos de desaniciu",
    "Files can’t be shared with create permissions" : "Los ficheros nun puen compartise colos permisos de creación",
    "Expiration date is in the past" : "La data de caducidá ta nel pasáu.",
    "Can’t set expiration date more than %s days in the future" : "Nun pue afitase la data de caducidá más de %s díes nel futuru",
    "Click the button below to open it." : "Primi'l botón d'embaxo p'abrilu.",
    "Could not find category \"%s\"" : "Nun pudo alcontrase la estaya \"%s.\"",
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sun." : "Dom.",
    "Mon." : "Llu.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Xue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Ll",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Xu",
    "Fr" : "Vi",
    "Sa" : "Sá",
    "January" : "Xineru",
    "February" : "Febreru",
    "March" : "Marzu",
    "April" : "Abril",
    "May" : "Mayu",
    "June" : "Xunu",
    "July" : "Xunetu",
    "August" : "Agostu",
    "September" : "Setiembre",
    "October" : "Ochobre",
    "November" : "Payares",
    "December" : "Avientu",
    "Jan." : "Xin.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Xun.",
    "Jul." : "Xnt.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Och.",
    "Nov." : "Pay.",
    "Dec." : "Avi.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Namái tan permitíos los siguientes caráuteres nun nome d'usuariu: \"a-z\", \"A-Z\", \"0-9\", y \"_.@-'\"",
    "A valid username must be provided" : "Tien d'apurrise un nome d'usuariu válidu",
    "Username contains whitespace at the beginning or at the end" : "El nome d'usuario contién espacios en blancu al entamu o al final",
    "Username must not consist of dots only" : "El nome d'usuariu nun pue tener puntos",
    "A valid password must be provided" : "Tien d'apurrise una contraseña válida",
    "The username is already being used" : "El nome d'usuariu yá ta usándose",
    "User disabled" : "Usuariu desactiváu",
    "Login canceled by app" : "Aniciar sesión canceláu pola aplicación",
    "a safe home for all your data" : "un llar seguru pa tolos tos datos",
    "File is currently busy, please try again later" : "Fichaeru ta ocupáu, por favor intentelo de nuevu más tarde",
    "Can't read file" : "Nun ye a lleese'l ficheru",
    "Application is not enabled" : "L'aplicación nun ta habilitada",
    "Authentication error" : "Fallu d'autenticación",
    "Token expired. Please reload page." : "Token caducáu. Recarga la páxina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nun hai controladores de bases de datos  (sqlite, mysql, o postgresql)",
    "Cannot write into \"config\" directory" : "Nun pue escribise nel direutoriu \"config\"",
    "Cannot write into \"apps\" directory" : "Nun pue escribise nel direutoriu \"apps\"",
    "Cannot create \"data\" directory" : "Nun pue crease'l direutoriu «datos»",
    "Setting locale to %s failed" : "Falló l'activación del idioma %s",
    "Please install one of these locales on your system and restart your webserver." : "Instala ún d'estos locales nel to sistema y reanicia'l sirvidor web",
    "Please ask your server administrator to install the module." : "Por favor, entrúga-y al to alministrador del sirvidor pa instalar el módulu.",
    "PHP module %s not installed." : "Nun ta instaláu'l módulu PHP %s",
    "PHP setting \"%s\" is not set to \"%s\"." : "La configuración de PHP \"%s\" nun s'afita \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload afita \"%s\" en llugar del valor esperáu \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pa solucionar esti problema definíu <code>mbstring.func_overload</code>a <code>0</code> nel so php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 ríquese siquier. Anguaño ta instaláu  %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Pa solucionar esti problema actualiza latso versión de libxml2 y reanicia'l to sirvidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ta aparentemente configuráu pa desaniciar bloques de documentos en llinia. Esto va facer que delles aplicaciones principales nun tean accesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse los módulos PHP, ¿pero tán entá llistaos como faltantes?",
    "Please ask your server administrator to restart the web server." : "Por favor, entruga al to alministrador pa reaniciar el sirvidor web.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requeríu",
    "Please upgrade your database version" : "Por favor, anueva la versión de la to base de datos",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, camuda los permisos a 0770 pa que'l direutoriu nun pueda llistase por otros usuarios.",
    "Check the value of \"datadirectory\" in your configuration" : "Comprobar el valor del \"datadirectory\" na so configuración",
    "Your data directory is invalid" : "El to direutoriu de datos nun ye válidu",
    "Could not obtain lock type %d on \"%s\"." : "Nun pudo facese'l bloquéu %d en \"%s\".",
    "Storage unauthorized. %s" : "Almacenamientu desautorizáu. %s",
    "Storage incomplete configuration. %s" : "Configuración d'almacenamientu incompleta. %s",
    "Storage connection error. %s" : "Fallu de conexón al almacenamientu. %s",
    "Storage is temporarily not available" : "L'almacenamientu ta temporalmente non disponible",
    "Storage connection timeout. %s" : "Tiempu escosao de conexón al almacenamientu. %s",
    "Create" : "Crear",
    "Change" : "Camudar",
    "Delete" : "Desaniciar",
    "Share" : "Share",
    "Unlimited" : "Non llendáu",
    "Verifying" : "Verificando",
    "Verifying …" : "Verificando...",
    "Verify" : "Verificar",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Compartir %s falló, por cuenta qu'el backend nun dexa acciones de tipu %i",
    "Sharing %s failed, because the file does not exist" : "Compartir %s falló, porque'l ficheru nun esiste",
    "Sharing %s failed, because you can not share with yourself" : "Compartir %s falló, porque nun puede compartise contigo mesmu",
    "You need to provide a password to create a public link, only protected links are allowed" : "Necesites apurrir una contraseña pa crear un enllaz públicu, namái tan permitíos los enllaces protexíos",
    "Sharing %s failed, because sharing with links is not allowed" : "Compartir %s falló, porque nun se permite compartir con enllaces",
    "Not allowed to create a federated share with the same user" : "Nun s'almite crear un recursu compartíu federáu col mesmu usuariu",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nun pue afitase la data de caducidá. Ficheros compartíos nun puen caducar dempués de %s de compartise",
    "Cannot set expiration date. Expiration date is in the past" : "Nun pue afitase la data d'espiración. La data d'espiración ta nel pasáu",
    "Sharing failed, because the user %s is the original sharer" : "Compartir falló, porque l'usuariu %s ye'l compartidor orixinal",
    "Sharing %s failed, because resharing is not allowed" : "Compartir %s falló, porque nun se permite la re-compartición",
    "Sharing %s failed, because the file could not be found in the file cache" : "Compartir %s falló, yá que'l ficheru nun pudo atopase na caché de ficheru"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ast.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "¡Nun pue escribise nel direutoriu «config»!",
    "See %s" : "Mira %s",
    "Sample configuration detected" : "Configuración d'amuesa detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectose que la configuración d'amuesa copiose. Esto pue encaboxar la instalación y dexala ensín soporte. Llee la documentación enantes de facer cambéos en config.php",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "Education Edition" : "Edición educativa",
    "Enterprise bundle" : "Llote empresarial",
    "Social sharing bundle" : "Llote de compartición social",
    "PHP %s or higher is required." : "Necesítase PHP %s o superior",
    "PHP with a version lower than %s is required." : "Necesítase una versión PHP anterior a %s",
    "%sbit or higher PHP required." : "Necesítase PHP %sbit o superior",
    "The command line tool %s could not be found" : "La ferramienta línea de comandu %s nun pudo alcontrase",
    "The library %s is not available." : "La librería %s nun ta disponible",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Triba de ficheru desconocida",
    "Invalid image" : "Imaxe inválida",
    "Avatar image is not square" : "La imaxe del avatar nun ye cuadrada",
    "today" : "güei",
    "tomorrow" : "mañana",
    "yesterday" : "ayeri",
    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n díes"],
    "last month" : "mes caberu",
    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
    "last year" : "añu caberu",
    "_%n year ago_::_%n years ago_" : ["hai %n añu","hai %n años"],
    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n hores"],
    "_%n minute ago_::_%n minutes ago_" : ["hai %n minutu","hai %n minutos"],
    "seconds ago" : "hai segundos",
    "File already exists" : "Yá esiste'l ficheru",
    "File name is a reserved word" : "El nome de ficheru ye una pallabra reservada",
    "File name contains at least one invalid character" : "El nome del ficheru contién polo menos un carácter non válidu",
    "File name is too long" : "El nome de ficheru ye demasiáu llargu",
    "Empty filename is not allowed" : "Nun s'almite un nome de ficheru baleru",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'aplicación \"%s\" nun puede instalase porque nun se llee'l ficheru appinfo.",
    "__language_name__" : "Asturianu",
    "Help" : "Ayuda",
    "Apps" : "Aplicaciones",
    "Settings" : "Settings",
    "Log out" : "Zarrar sesión",
    "Users" : "Usuarios",
    "Email" : "email",
    "Phone" : "Teléfonu",
    "Twitter" : "Twitter",
    "Website" : "Sitiu web",
    "Address" : "Direición",
    "Profile picture" : "Semeya de perfil",
    "About" : "Tocante a",
    "Full name" : "Nome completu",
    "Unknown user" : "Usuariu desconocíu",
    "Additional settings" : "Axustes adicionales",
    "You need to enter details of an existing account." : "Precises introducir los detalles d'una cuenta esistente.",
    "Oracle connection could not be established" : "Nun pudo afitase la conexón d'Oracle",
    "Oracle username and/or password not valid" : "Nome d'usuariu o contraseña d'Oracle non válidos",
    "PostgreSQL username and/or password not valid" : "Nome d'usuariu o contraseña PostgreSQL non válidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nun ta sofitáu y %s nun furrulará afayadizamente nesta plataforma. ¡Úsalu baxo'l to riesgu!",
    "For the best results, please consider using a GNU/Linux server instead." : "Pa los meyores resultaos, por favor considera l'usu d'un sirvidor GNU/Linux nel so llugar.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Paez ser que la instancia %s ta executándose nun entornu de PHP 32 bits y el open_basedir configuróse en php.ini. Esto va dar llugar a problemes colos ficheros de más de 4 GB y nun ye nada recomendable.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, desanicia la configuración open_basedir dientro la so php.ini o camude a PHP 64 bits.",
    "Set an admin username." : "Afitar nome d'usuariu p'almin",
    "Set an admin password." : "Afitar contraseña p'almin",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartíu %s tien d'implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "Nun s'alcontró'l botón de compartición %s",
    "Sharing backend for %s not found" : "Nun s'alcontró'l botón de partición pa %s",
    "Open »%s«" : "Abrir «%s»",
    "You are not allowed to share %s" : "Nun tienes permisu pa compartir %s",
    "Cannot increase permissions of %s" : "Nun se pueden aumentar los permisos de %s",
    "Expiration date is in the past" : "La data de caducidá ta nel pasáu.",
    "Sharing %s failed, because this item is already shared with user %s" : "Compartir %s falló, porque esti elementu yá ta compartiéndose col usuariu %s",
    "Click the button below to open it." : "Primi'l botón d'embaxo p'abrilu.",
    "Could not find category \"%s\"" : "Nun pudo alcontrase la estaya \"%s.\"",
    "Sunday" : "Domingu",
    "Monday" : "Llunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Xueves",
    "Friday" : "Vienres",
    "Saturday" : "Sábadu",
    "Sun." : "Dom.",
    "Mon." : "Llu.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Xue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Ll",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Xu",
    "Fr" : "Vi",
    "Sa" : "Sá",
    "January" : "Xineru",
    "February" : "Febreru",
    "March" : "Marzu",
    "April" : "Abril",
    "May" : "Mayu",
    "June" : "Xunu",
    "July" : "Xunetu",
    "August" : "Agostu",
    "September" : "Setiembre",
    "October" : "Ochobre",
    "November" : "Payares",
    "December" : "Avientu",
    "Jan." : "Xin.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Xun.",
    "Jul." : "Xnt.",
    "Aug." : "Ago.",
    "Sep." : "Set.",
    "Oct." : "Och.",
    "Nov." : "Pay.",
    "Dec." : "Avi.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Namái tan permitíos los siguientes caráuteres nun nome d'usuariu: \"a-z\", \"A-Z\", \"0-9\", y \"_.@-'\"",
    "A valid username must be provided" : "Tien d'apurrise un nome d'usuariu válidu",
    "Username contains whitespace at the beginning or at the end" : "El nome d'usuario contién espacios en blancu al entamu o al final",
    "Username must not consist of dots only" : "El nome d'usuariu nun pue tener puntos",
    "A valid password must be provided" : "Tien d'apurrise una contraseña válida",
    "The username is already being used" : "El nome d'usuariu yá ta usándose",
    "User disabled" : "Usuariu desactiváu",
    "Login canceled by app" : "Aniciar sesión canceláu pola aplicación",
    "a safe home for all your data" : "un llar seguru pa tolos tos datos",
    "File is currently busy, please try again later" : "Fichaeru ta ocupáu, por favor intentelo de nuevu más tarde",
    "Application is not enabled" : "L'aplicación nun ta habilitada",
    "Authentication error" : "Fallu d'autenticación",
    "Token expired. Please reload page." : "Token caducáu. Recarga la páxina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nun hai controladores de bases de datos  (sqlite, mysql, o postgresql)",
    "PHP module %s not installed." : "Nun ta instaláu'l módulu PHP %s",
    "Please ask your server administrator to install the module." : "Por favor, entrúga-y al to alministrador del sirvidor pa instalar el módulu.",
    "PHP setting \"%s\" is not set to \"%s\"." : "La configuración de PHP \"%s\" nun s'afita \"%s\".",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 ríquese siquier. Anguaño ta instaláu  %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Pa solucionar esti problema actualiza latso versión de libxml2 y reanicia'l to sirvidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ta aparentemente configuráu pa desaniciar bloques de documentos en llinia. Esto va facer que delles aplicaciones principales nun tean accesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dablemente esto seya culpa d'un caché o acelerador, como por exemplu Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse los módulos PHP, ¿pero tán entá llistaos como faltantes?",
    "Please ask your server administrator to restart the web server." : "Por favor, entruga al to alministrador pa reaniciar el sirvidor web.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, camuda los permisos a 0770 pa que'l direutoriu nun pueda llistase por otros usuarios.",
    "Could not obtain lock type %d on \"%s\"." : "Nun pudo facese'l bloquéu %d en \"%s\".",
    "Storage unauthorized. %s" : "Almacenamientu desautorizáu. %s",
    "Storage incomplete configuration. %s" : "Configuración d'almacenamientu incompleta. %s",
    "Storage connection error. %s" : "Fallu de conexón al almacenamientu. %s",
    "Storage is temporarily not available" : "L'almacenamientu ta temporalmente non disponible",
    "Storage connection timeout. %s" : "Tiempu escosao de conexón al almacenamientu. %s",
    "%s enter the database username and name." : "%s introducir el nome d'usuariu y el nome de la base de datos .",
    "%s enter the database username." : "%s introducir l'usuariu de la base de datos.",
    "%s enter the database name." : "%s introducir nome de la base de datos.",
    "%s you may not use dots in the database name" : "%s nun pues usar puntos nel nome de la base de datos",
    "Cannot write into \"config\" directory" : "Nun pue escribise nel direutoriu \"config\"",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Esto davezu íguase dando'l permisu d'escritura nel direutoriu de configuración al sirvidor web. Mira %s",
    "Cannot write into \"apps\" directory" : "Nun pue escribise nel direutoriu \"apps\"",
    "Cannot create \"data\" directory" : "Nun pue crease'l direutoriu «datos»",
    "Setting locale to %s failed" : "Falló l'activación del idioma %s",
    "Please install one of these locales on your system and restart your webserver." : "Instala ún d'estos locales nel to sistema y reanicia'l sirvidor web",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload afita \"%s\" en llugar del valor esperáu \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pa solucionar esti problema definíu <code>mbstring.func_overload</code>a <code>0</code> nel so php.ini",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requeríu",
    "Please upgrade your database version" : "Por favor, anueva la versión de la to base de datos",
    "Check the value of \"datadirectory\" in your configuration" : "Comprobar el valor del \"datadirectory\" na so configuración",
    "Your data directory is invalid" : "El to direutoriu de datos nun ye válidu"
},
"nplurals=2; plural=(n != 1);");
